@@ -9,7 +9,7 @@ import requests
 from .version import __version__
 
 CONNECT_SERVICE_LOC = "https://api.materialsdatafacility.org"
-CONNECT_DEV_LOC = "https://dev-api.materialsdatafacility.org"
+CONNECT_DEV_LOC = "https://f6avec0img.execute-api.us-east-1.amazonaws.com/test"
 CONNECT_EXTRACT_ROUTE = "/submit"
 CONNECT_STATUS_ROUTE = "/status/"
 CONNECT_ALL_STATUS_ROUTE = "/submissions/"
@@ -29,7 +29,7 @@ class MDFConnectClient:
     """The MDF Connect Client is the Python client to easily submit datasets to MDF Connect."""
     __app_name = "MDF_Connect_Client"
     __client_id = "fcb9bf5a-4492-4e25-970f-510b69abc964"
-    __login_services = ["mdf_connect"]
+    __login_services = ["mdf_connect", "mdf_connect_dev"]
     __allowed_authorizers = [
         globus_sdk.AccessTokenAuthorizer,
         globus_sdk.RefreshTokenAuthorizer,
@@ -77,13 +77,14 @@ class MDFConnectClient:
         self.md_update_route = CONNECT_MD_UPDATE_ROUTE
 
         self.reset_submission()
+        login_service = "mdf_connect" if self.service_loc == CONNECT_SERVICE_LOC else "mdf_connect_dev"
 
         if any([isinstance(authorizer, allowed) for allowed in self.__allowed_authorizers]):
             self.__authorizer = authorizer
         else:
             self.__authorizer = mdf_toolbox.login(services=self.__login_services,
                                                   client_id=self.__client_id,
-                                                  app_name=self.__app_name).get("mdf_connect")
+                                                  app_name=self.__app_name).get(login_service)
         if not self.__authorizer:
             raise ValueError("Unable to authenticate")
 
@@ -417,6 +418,22 @@ class MDFConnectClient:
         """Clear all added organizations from the submission."""
         self.mdf.pop("organizations", None)
 
+    def add_links(self, links):
+        """Add links to a dataset.
+
+        Arguments:
+            link (str or list of str): The link(s) to add.
+                   Should be of the form {"type":str, "doi":str, "url":str, "description":str, "bibtex":str}
+        """
+        if not isinstance(links, list):
+            links = [links]
+        if not self.mdf.get("links"):
+            self.mdf["links"] = links
+
+    def clear_links(self):
+        """Clear all tags added so far to your dataset."""
+        self.links = []
+
     # ***********************************************
     # * Optional inputs
     # ***********************************************
@@ -668,6 +685,8 @@ class MDFConnectClient:
             submission["services"] = self.services
         if self.tags:
             submission["tags"] = self.tags
+        if self.links:
+            submission["links"] = self.links
         if self.curation:
             submission["curation"] = self.curation
         if self.no_extract:
@@ -710,6 +729,7 @@ class MDFConnectClient:
         self.clear_index()
         self.clear_services()
         self.clear_tags()
+        self.clear_links()
         self.clear_dataset_acl()
 
         self.source_id = None
@@ -780,13 +800,13 @@ class MDFConnectClient:
 
         # Make the request
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        self.__authorizer.get_authorization_header()
         res = requests.post(self.service_loc+self.extract_route,
                             json=submission, headers=headers)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.post(self.service_loc+self.extract_route,
                                 json=submission, headers=headers)
 
@@ -861,13 +881,13 @@ class MDFConnectClient:
 
         # Make the request
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         res = requests.post(self.service_loc+self.md_update_route+source_id,
                             json=metadata_update, headers=headers)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.post(self.service_loc+self.md_update_route+source_id,
                                 json=metadata_update, headers=headers)
 
@@ -925,13 +945,13 @@ class MDFConnectClient:
             print("Error: No dataset submitted")
             return None
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         res = requests.get(self.service_loc+self.status_route+(source_id or self.source_id),
                            headers=headers)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.get(self.service_loc+self.status_route+(source_id or self.source_id),
                                headers=headers)
 
@@ -1059,7 +1079,7 @@ class MDFConnectClient:
             filters.append(("submission_time", "<=", older_than_date.isoformat("T") + "Z"))
 
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         body = {
             "filters": filters
         }
@@ -1068,7 +1088,7 @@ class MDFConnectClient:
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.post(url, headers=headers, json=body)
 
         try:
@@ -1149,12 +1169,12 @@ class MDFConnectClient:
             if raw is ``True``, *dict*: The full task results.
         """
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         res = requests.get(self.service_loc+self.curation_route+source_id, headers=headers)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.get(self.service_loc+self.curation_route+source_id, headers=headers)
 
         try:
@@ -1181,10 +1201,10 @@ class MDFConnectClient:
             elif summary:
                 task = json_res["curation_task"]
                 print(self.curation_summary_template.format(
-                                source_id=task["source_id"],
-                                submitter=task["submission_info"]["submitter"],
-                                waiting_since=task["curation_start_date"],
-                                extraction_summary=task["extraction_summary"]))
+                    source_id=task["source_id"],
+                    submitter=task["submission_info"]["submitter"],
+                    waiting_since=task["curation_start_date"],
+                    extraction_summary=task["extraction_summary"]))
             else:
                 task = json_res["curation_task"]
                 # TODO: Are the dataset and record entries human-useful?
@@ -1219,13 +1239,13 @@ class MDFConnectClient:
             if raw is ``True``, *dict*: The full task results.
         """
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         res = requests.get(self.service_loc+self.all_curation_route+(_admin_code or ""),
                            headers=headers)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.get(self.service_loc+self.all_curation_route+(_admin_code or ""),
                                headers=headers)
         try:
@@ -1256,10 +1276,10 @@ class MDFConnectClient:
                 print()  # Newline for spacing
                 for task in json_res["curation_tasks"]:
                     print(self.curation_summary_template.format(
-                                    source_id=task["source_id"],
-                                    submitter=task["submission_info"]["submitter"],
-                                    waiting_since=task["curation_start_date"],
-                                    extraction_summary=task["extraction_summary"]))
+                        source_id=task["source_id"],
+                        submitter=task["submission_info"]["submitter"],
+                        waiting_since=task["curation_start_date"],
+                        extraction_summary=task["extraction_summary"]))
             else:
                 for task in json_res["curation_tasks"]:
                     # TODO: Are the dataset and record entries human-useful?
@@ -1363,13 +1383,13 @@ class MDFConnectClient:
             "reason": reason
         }
         headers = {}
-        self.__authorizer.set_authorization_header(headers)
+        headers["Authorization"] = self.__authorizer.get_authorization_header()
         res = requests.post(self.service_loc+self.curation_route+source_id, headers=headers,
                             json=command)
         # Handle first 401/403 by regenerating auth headers
         if res.status_code == 401 or res.status_code == 403:
             self.__authorizer.handle_missing_authorization()
-            self.__authorizer.set_authorization_header(headers)
+            headers["Authorization"] = self.__authorizer.get_authorization_header()
             res = requests.get(self.service_loc+self.curation_route+source_id, headers=headers,
                                json=command)
 
